@@ -1,6 +1,6 @@
 package Test::TestCoverage;
 
-# ABSTRACT - Test if your test covers all "public" subroutines of the package
+# ABSTRACT: Test if your test covers all "public" subroutines of the package
 
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ our @EXPORT = qw(
                  reset_all_test_coverage
                  test_coverage_except
                 );
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 my $self    = {};
 my $test    = Test::Builder->new();
@@ -46,23 +46,29 @@ sub test_coverage {
         no strict 'refs';
         no warnings 'redefine';
         
-        my $old     = $package->can( $sub );
-        
-        if ( !$moosified ) {
-            *{ $package . '::' . $sub } = sub {
-                $invokes->{$package}->{$sub}++; 
-                $old->( @_ );
-            };
-        }
-        else {
+        my $old    = $package->can( $sub );
+        my $mopped = 0;
+
+        if ( $moosified ) {
             require Class::MOP;
             my $meta
                 = $package->can('add_before_method_modifier')
                 ? $package
                 : Class::MOP::class_of( $package );
-            $meta->add_after_method_modifier( $sub, sub {
+
+            if ( defined $meta ) {
+                $mopped++;
+                $meta->add_after_method_modifier( $sub, sub {
+                    $invokes->{$package}->{$sub}++; 
+                } );
+            }
+        }
+
+        if ( !$mopped ) {
+            *{ $package . '::' . $sub } = sub {
                 $invokes->{$package}->{$sub}++; 
-            } );
+                $old->( @_ );
+            };
         }
     }
         
@@ -175,12 +181,21 @@ sub _get_sub {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Test::TestCoverage - Test if your test covers all "public" subroutines of the package
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   use Test::TestCoverage;
@@ -264,7 +279,6 @@ C<reset_all_test_coverage>, C<test_coverage_except>
 
 L<Test::SubCalls>, L<Test::Builder>, L<Test::More>, L<Devel::Cover>
 
-
 =head1 BUGS / TODO
 
 There are a lot of things to do. If you experience any problems please contact
@@ -273,14 +287,14 @@ Exported subroutines are not detected.
 
 =head1 AUTHOR
 
-Renee Baecker, E<lt>module@renee-baecker.deE<gt>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Renee Baecker
+This software is Copyright (c) 2014 by Renee Baecker.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
