@@ -1,4 +1,5 @@
-package TestCoverage::Foobar;
+package
+   TestCoverage::Foobar;
 
 use strict;
 use warnings;
@@ -22,3 +23,4 @@ sub BUILD {
 }
 
 1;
+
