@@ -1,4 +1,5 @@
-package TestCoverage::MyTestModule;
+package
+   TestCoverage::MyTestModule;
 
 use strict;
 use warnings;
@@ -11,4 +12,4 @@ sub methode{
     return "Methode\n";
 }
 
-1;
\ No newline at end of file
+1;
